@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 
 use Class::Accessor::Lite (
-    ro => [qw(attribute position)],
+    ro => [qw(attribute position expect actual)],
 );
 
 sub new {
@@ -15,6 +15,13 @@ sub new {
     }, $class;
 }
 
+sub set_detail {
+    my ($self, %params) = @_;
+
+    $self->{expected} = $params{expected};
+    $self->{actual} = $params{actual};
+}
+
 sub as_message {
     my ($self) = @_;
     return sprintf 'invalid `%s` at `%s`.',
